==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ObjectFieldSelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ObjectFieldSelectorBuilder extends io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ObjectFieldSelector,io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder>{
  public ObjectFieldSelectorBuilder() {
    this(false);
  }
  public ObjectFieldSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ObjectFieldSelector(), validationEnabled);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ObjectFieldSelector(), validationEnabled);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ObjectFieldSelector instance) {
    this(fluent, instance, false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ObjectFieldSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    this.validationEnabled = validationEnabled; 
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelector instance) {
    this(instance,false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector build() {
    ObjectFieldSelector buildable = new ObjectFieldSelector(fluent.getApiVersion(),fluent.getFieldPath());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectFieldSelectorBuilder that = (ObjectFieldSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/ObjectFieldSelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ObjectFieldSelectorBuilder extends io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ObjectFieldSelector,io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder>{
  public ObjectFieldSelectorBuilder() {
    this(false);
  }
  public ObjectFieldSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ObjectFieldSelector(), validationEnabled);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ObjectFieldSelector(), validationEnabled);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ObjectFieldSelector instance) {
    this(fluent, instance, false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ObjectFieldSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelector instance) {
    this(instance,false);
  }
  public ObjectFieldSelectorBuilder(io.fabric8.kubernetes.api.model.ObjectFieldSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector build() {
    ObjectFieldSelector buildable = new ObjectFieldSelector(fluent.getApiVersion(),fluent.getFieldPath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectFieldSelectorBuilder that = (ObjectFieldSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
